@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.018';
+our $VERSION = '0.019';
 
 use Moose;
 
@@ -14,7 +14,13 @@ with qw(
   Dist::Zilla::Role::TextTemplate
 );
 
-sub mvp_multivalue_args { return (qw( stopwords travis_ci_ignore_perl )) }
+sub mvp_multivalue_args { return (qw( skip_file stopwords travis_ci_ignore_perl )) }
+
+has skip_file => (
+    is      => 'ro',
+    isa     => 'Maybe[ArrayRef]',
+    default => sub { [] },
+);
 
 has stopwords => (
     is      => 'ro',
@@ -104,8 +110,14 @@ sub munge_files {
 sub _write_files {
     my ($self) = @_;
 
+    my %file_to_skip = map { $_ => 1 } grep { defined && !m{ ^ \s* $ }xsm } @{ $self->skip_file };
+
   FILE:
     for my $file ( map { path($_) } sort $self->files() ) {
+        if ( exists $file_to_skip{$file} ) {
+            next FILE;
+        }
+
         if ( -e $file ) {
             $file->remove();
         }
@@ -138,7 +150,7 @@ Dist::Zilla::Plugin::Author::SKIRMESS::RepositoryBase - Automatically create and
 
 =head1 VERSION
 
-Version 0.018
+Version 0.019
 
 =head1 SYNOPSIS
 
@@ -461,7 +473,9 @@ TRAVIS_YML_1
 
         my %perl;
         @perl{ @{ $self->_travis_available_perl } } = ();
-        delete @perl{ @{ $self->travis_ci_ignore_perl } };
+        if ( @{ $self->travis_ci_ignore_perl } ) {
+            delete @perl{ @{ $self->travis_ci_ignore_perl } };
+        }
         my @perl = reverse sort keys %perl;
 
         croak "No perl versions selected for TravisCI\n" if !@perl;
@@ -684,6 +698,18 @@ use Test::CPAN::Changes;
 changes_ok();
 XT_RELEASE_CHANGES_T
 
+=head2 xt/release/distmeta.t
+
+L<Test::CPAN::Meta|Test::CPAN::Meta> release test.
+
+=cut
+
+    $file{q{xt/release/distmeta.t}} = $test_header . <<'XT_RELEASE_DISTMETA_T';
+use Test::CPAN::Meta;
+
+meta_yaml_ok();
+XT_RELEASE_DISTMETA_T
+
 =head2 xt/release/eol.t
 
 L<Test::EOL|Test::EOL> release test.
@@ -759,6 +785,10 @@ __END__
 
 The following configuration options are supported:
 
+=head2 skip_file
+
+Defines files to be skipped (not generated).
+
 =head2 stopwords
 
 Defines stopwords for the spell checker.
